var indexSectionsWithContent =
{
  0: "acdeikmprstuw~",
  1: "w",
  2: "aimprstuw~",
  3: "cdekrsw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Functions",
  3: "Pages"
};

